=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-08-17 13:32:02 +0000
+++ bzrlib/tests/__init__.py	2006-08-24 08:20:26 +0000
@@ -69,7 +69,7 @@
 import bzrlib.trace
 from bzrlib.transport import get_transport
 import bzrlib.transport
-from bzrlib.transport.local import LocalRelpathServer
+from bzrlib.transport.local import LocalURLServer
 from bzrlib.transport.readonly import ReadonlyServer
 from bzrlib.trace import mutter
 from bzrlib.tests import TestUtil
@@ -81,7 +81,7 @@
 import bzrlib.urlutils as urlutils
 from bzrlib.workingtree import WorkingTree, WorkingTreeFormat2
 
-default_transport = LocalRelpathServer
+default_transport = LocalURLServer
 
 MODULES_TO_TEST = []
 MODULES_TO_DOCTEST = [

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-08-22 17:02:22 +0000
+++ bzrlib/tests/test_selftest.py	2006-08-24 08:20:26 +0000
@@ -439,9 +439,9 @@
 
     def test_get_readonly_url_http(self):
         from bzrlib.transport import get_transport
-        from bzrlib.transport.local import LocalRelpathServer
+        from bzrlib.transport.local import LocalURLServer
         from bzrlib.transport.http import HttpServer, HttpTransportBase
-        self.transport_server = LocalRelpathServer
+        self.transport_server = LocalURLServer
         self.transport_readonly_server = HttpServer
         # calling get_readonly_transport() gives us a HTTP server instance.
         url = self.get_readonly_url()

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2006-07-28 16:52:19 +0000
+++ bzrlib/tests/test_transport.py	2006-08-24 08:20:26 +0000
@@ -38,6 +38,10 @@
                               )
 from bzrlib.transport.memory import MemoryTransport
 from bzrlib.transport.local import LocalTransport
+from bzrlib import urlutils
+
+
+# TODO: Should possibly split transport-specific tests into their own files.
 
 
 class TestTransport(TestCase):
@@ -319,8 +323,8 @@
         server = fakenfs.FakeNFSServer()
         server.setUp()
         try:
-            # the server should be a relpath localhost server
-            self.assertEqual(server.get_url(), 'fakenfs+.')
+            # the url should be decorated appropriately
+            self.assertTrue(server.get_url().startswith('fakenfs+'))
             # and we should be able to get a transport for it
             transport = get_transport(server.get_url())
             # which must be a FakeNFSTransportDecorator instance.
@@ -414,3 +418,25 @@
             # regular connection behaviour by direct construction.
             t = self.transport_class(base_url)
         return t
+
+
+class TestLocalTransports(TestCase):
+
+    def test_get_transport_from_abspath(self):
+        here = os.path.abspath('.')
+        t = get_transport(here)
+        self.assertIsInstance(t, LocalTransport)
+        self.assertEquals(t.base, urlutils.local_path_to_url(here) + '/')
+
+    def test_get_transport_from_relpath(self):
+        here = os.path.abspath('.')
+        t = get_transport('.')
+        self.assertIsInstance(t, LocalTransport)
+        self.assertEquals(t.base, urlutils.local_path_to_url(here) + '/')
+
+    def test_get_transport_from_local_url(self):
+        here = os.path.abspath('.')
+        here_url = urlutils.local_path_to_url(here) + '/'
+        t = get_transport(here_url)
+        self.assertIsInstance(t, LocalTransport)
+        self.assertEquals(t.base, here_url)

=== modified file 'bzrlib/transport/decorator.py'
--- bzrlib/transport/decorator.py	2006-07-28 16:05:23 +0000
+++ bzrlib/transport/decorator.py	2006-08-24 08:20:26 +0000
@@ -153,9 +153,9 @@
             self._made_server = False
             self._server = server
         else:
-            from bzrlib.transport.local import LocalRelpathServer
+            from bzrlib.transport.local import LocalURLServer
             self._made_server = True
-            self._server = LocalRelpathServer()
+            self._server = LocalURLServer()
             self._server.setUp()
 
     def tearDown(self):

=== modified file 'bzrlib/transport/local.py'
--- bzrlib/transport/local.py	2006-08-16 19:15:19 +0000
+++ bzrlib/transport/local.py	2006-08-24 08:20:26 +0000
@@ -361,7 +361,11 @@
 
 
 class LocalURLServer(Server):
-    """A pretend server for local transports, using file:// urls."""
+    """A pretend server for local transports, using file:// urls.
+    
+    Of course no actual server is required to access the local filesystem, so
+    this just exists to tell the test code how to get to it.
+    """
 
     def get_url(self):
         """See Transport.Server.get_url."""
@@ -370,7 +374,6 @@
 
 def get_test_permutations():
     """Return the permutations to be used in testing."""
-    return [(LocalTransport, LocalRelpathServer),
-            (LocalTransport, LocalAbspathServer),
+    return [
             (LocalTransport, LocalURLServer),
             ]

